@@ -9,6 +9,7 @@ import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTSessionExpire
 import org.gcube.portlets.user.td.gwtservice.shared.rule.ApplyTableRuleSession;
 import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialog;
 import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialogListener;
+import org.gcube.portlets.user.td.widgetcommonevent.client.CommonMessages;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.SessionExpiredEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.SessionExpiredType;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.OperationResult;
@@ -16,6 +17,7 @@ import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
 import org.gcube.portlets.user.td.wizardwidget.client.WizardCard;
 
 import com.allen_sauer.gwt.log.client.Log;
+import com.google.gwt.core.client.GWT;
 import com.google.gwt.safehtml.shared.SafeHtmlBuilder;
 import com.google.gwt.user.client.Command;
 import com.google.gwt.user.client.rpc.AsyncCallback;
@@ -36,15 +38,18 @@ import com.sencha.gxt.widget.core.client.container.VBoxLayoutContainer.VBoxLayou
  */
 public class RuleOnTableApplyOperationInProgressCard extends WizardCard
 		implements MonitorDialogListener {
-
+	private static RuleOnTableApplyMessages msgs=GWT.create(RuleOnTableApplyMessages.class);
+	private CommonMessages msgsCommon;
+	
 	private HtmlLayoutContainer resultField;
 	private ApplyTableRuleSession applyTableRuleSession;
 
 	public RuleOnTableApplyOperationInProgressCard(
 			ApplyTableRuleSession applyTableRuleSession) {
-		super("Apply Rule On Table", "");
-
+		super(msgs.ruleOnTableApplyOperationInProgressCardHead(), "");
 		this.applyTableRuleSession = applyTableRuleSession;
+		initMessages();
+		
 		VBoxLayoutContainer operationInProgressPanel = new VBoxLayoutContainer();
 		operationInProgressPanel.setVBoxLayoutAlign(VBoxLayoutAlign.CENTER);
 
@@ -56,16 +61,16 @@ public class RuleOnTableApplyOperationInProgressCard extends WizardCard
 
 		// display:block;vertical-align:text-top;
 		description.setHTML(0, 0,
-				"<span style=\"font-weight:bold;\";>Rule Name: </span>");
+				"<span style=\"font-weight:bold;\";>"+msgs.ruleNameLabel()+"</span>");
 		description.setText(0, 1, applyTableRuleSession
 				.getRuleDescriptionData().getName());
 		description.setHTML(1, 0,
-				"<span style=\"font-weight:bold;\";>Rule Description: </span>");
+				"<span style=\"font-weight:bold;\";>"+msgs.ruleDescriptionLabel()+"</span>");
 		description.setText(1, 1, applyTableRuleSession
 				.getRuleDescriptionData().getDescription());
 
 		FramedPanel summary = new FramedPanel();
-		summary.setHeadingText("Rule On Table");
+		summary.setHeadingText(msgs.summaryHead());
 		summary.setWidth(400);
 		summary.add(description);
 		operationInProgressPanel.add(summary, new BoxLayoutData(new Margins(20,
@@ -80,6 +85,10 @@ public class RuleOnTableApplyOperationInProgressCard extends WizardCard
 		resultField.setVisible(false);
 
 	}
+	
+	protected void initMessages(){
+		msgsCommon=GWT.create(CommonMessages.class);
+	}
 
 	public void applyTableRule() {
 		ExpressionServiceAsync.INSTANCE.startApplyTableRule(applyTableRuleSession,
@@ -99,11 +108,11 @@ public class RuleOnTableApplyOperationInProgressCard extends WizardCard
 						} else {
 							if (caught instanceof TDGWTIsLockedException) {
 								Log.error(caught.getLocalizedMessage());
-								showErrorAndHide("Error","Error ",
+								showErrorAndHide(msgsCommon.errorLocked(),msgsCommon.errorLocked(),
 										caught.getLocalizedMessage(), caught);
 							} else {
-								showErrorAndHide("Error",
-										"An error occured in apply rule on table: ",
+								showErrorAndHide(msgsCommon.error(),
+										msgs.errorInApplyRuleOnTable(),
 												caught.getLocalizedMessage(),
 										caught);
 
@@ -135,7 +144,7 @@ public class RuleOnTableApplyOperationInProgressCard extends WizardCard
 		final TRId newTrId = operationResult.getTrId();
 		SafeHtmlBuilder safeHtmlBuilder = new SafeHtmlBuilder();
 		safeHtmlBuilder
-				.appendHtmlConstant("<div style='text-align:center;font-size:large;font-weight:bold; color:#009900;'>Operation Completed</div>");
+				.appendHtmlConstant("<div style='text-align:center;font-size:large;font-weight:bold; color:#009900;'>"+msgsCommon.operationCompleted()+"</div>");
 		resultField.setHTML(safeHtmlBuilder.toSafeHtml());
 		resultField.setVisible(true);
 
@@ -166,7 +175,7 @@ public class RuleOnTableApplyOperationInProgressCard extends WizardCard
 	public void operationFailed(Throwable caught, String reason, String details) {
 		SafeHtmlBuilder safeHtmlBuilder = new SafeHtmlBuilder();
 		safeHtmlBuilder
-				.appendHtmlConstant("<div style='text-align:center;font-size:large;font-weight:bold;color:red;'>Operation Failed</div>");
+				.appendHtmlConstant("<div style='text-align:center;font-size:large;font-weight:bold;color:red;'>"+msgsCommon.operationFailed()+"</div>");
 		resultField.setHTML(safeHtmlBuilder.toSafeHtml());
 		resultField.setVisible(true);
 		if (caught instanceof TDGWTSessionExpiredException) {
@@ -175,7 +184,7 @@ public class RuleOnTableApplyOperationInProgressCard extends WizardCard
 							new SessionExpiredEvent(
 									SessionExpiredType.EXPIREDONSERVER));
 		} else {
-			showErrorAndHide("Error",
+			showErrorAndHide(msgsCommon.error(),
 					reason,details,caught);
 		}
 
@@ -187,7 +196,7 @@ public class RuleOnTableApplyOperationInProgressCard extends WizardCard
 		final TRId newTrId = operationResult.getTrId();
 		SafeHtmlBuilder safeHtmlBuilder = new SafeHtmlBuilder();
 		safeHtmlBuilder
-				.appendHtmlConstant("<div style='text-align:center;font-size:large;font-weight:bold;color: #FF9900;'>Validation Failed</div>");
+				.appendHtmlConstant("<div style='text-align:center;font-size:large;font-weight:bold;color: #FF9900;'>"+msgsCommon.validationFailed()+"</div>");
 		resultField.setHTML(safeHtmlBuilder.toSafeHtml());
 		resultField.setVisible(true);
 
@@ -219,7 +228,7 @@ public class RuleOnTableApplyOperationInProgressCard extends WizardCard
 	public void operationAborted() {
 		SafeHtmlBuilder safeHtmlBuilder = new SafeHtmlBuilder();
 		safeHtmlBuilder
-				.appendHtmlConstant("<div style='text-align:center;font-size:large;font-weight:bold;color: #AA00AA;'>Operation Aborted</div>");
+				.appendHtmlConstant("<div style='text-align:center;font-size:large;font-weight:bold;color: #AA00AA;'>"+msgsCommon.operationAborted()+"</div>");
 		resultField.setHTML(safeHtmlBuilder.toSafeHtml());
 		resultField.setVisible(true);
 
@@ -249,7 +258,7 @@ public class RuleOnTableApplyOperationInProgressCard extends WizardCard
 	public void operationPutInBackground() {
 		SafeHtmlBuilder safeHtmlBuilder = new SafeHtmlBuilder();
 		safeHtmlBuilder
-				.appendHtmlConstant("<div style='text-align:center;font-size:large;font-weight:bold;color: #00AAAA;'>Operation in Background</div>");
+				.appendHtmlConstant("<div style='text-align:center;font-size:large;font-weight:bold;color: #00AAAA;'>"+msgsCommon.operationInBackground()+"</div>");
 		resultField.setHTML(safeHtmlBuilder.toSafeHtml());
 		resultField.setVisible(true);
 
